import * as React from 'react';
import {Typography} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {OrderModel} from "../../stores/OrderStore";
import {observer} from "mobx-react-lite";

type Props = {
    order: OrderModel,
    handleRefresh: () => void
}

export const ConfirmationError: React.FunctionComponent<Props> = observer(({ order, handleRefresh }) => {
    const [seconds, setSeconds] = React.useState(10);
    React.useEffect(() => {
        const id = setInterval(() => {
            if(seconds >= 0 ) {
                setSeconds(seconds => seconds - 1);
            }
        }, 1000);
        return () => clearInterval(id);
    })

    if(seconds === 0) {
        handleRefresh();
    }

    return(
        <>
            <Typography variant={"h5"} align={"center"}>
                <Trans>Order {order?.order_number} not found in Rx-Universe</Trans>
            </Typography>
            <Typography variant={"h6"} align={"center"}>
                <Trans>Ensure the remote order processor is running, otherwise please wait</Trans>
            </Typography>
            <Typography variant={"body1"} align={"center"}>
                <Trans>Refreshing in {seconds} seconds</Trans>
            </Typography>
        </>
    )
});