import * as React from 'react';
import {observer} from "mobx-react-lite";
import {SyncStatusModel} from "../../stores/SyncStatusStore";
import {ButtonField} from "@rx-suite/ui";
import {Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";

type Props = {
    model: SyncStatusModel
}
export const SyncErrorButton: React.FunctionComponent<Props> = observer(({ model }) => {
    const [open, setOpen] = React.useState(false);
    const handleClick = React.useCallback(() => {
        setOpen(true);
    }, [])

    const closeDialog = React.useCallback(() => {
        setOpen(false);
    }, []);

    return(
        <>
            <Dialog onClose={closeDialog} open={open}>
                <DialogTitle><Trans>Last Sync Error</Trans></DialogTitle>
                <DialogContent>
                    {model.error_message}
                </DialogContent>
                <DialogActions>
                    <ButtonField
                        text={t`Close`}
                        onClick={closeDialog}
                    />
                </DialogActions>
            </Dialog>
            <ButtonField
                text={t`View Error`}
                onClick={handleClick}
                disabled={!model.failed}
            />
        </>
    )
});