import * as React from 'react';
import {observer} from "mobx-react-lite";
import {
    Conditional,
    FormProps,
    IfTrue,
    LinkButton,
    ModelCheckbox,
    ModelForm,
    ModelInput,
    ModelSelect,
    PaddedPaper
} from "@rx-suite/ui";
import {Container, Grid, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {currentUserCan} from "@rx-suite/stores";
import {ConfigPDSelect} from "./ConfigPDSelect";
import {CustomersSelect} from "./CustomersSelect";
import {OrderColumnsSelect} from "./OrderColumnsSelect";
import {Edit} from "@material-ui/icons";

const JOBTYPE_OPTIONS = [
    {value: "", label: t`No Default`},
    {value: "P", label: t`Pair`},
    {value: "R", label: t`Right`},
    {value: "L", label: t`Left`},
    {value: "RB", label: t`Right Balance`},
    {value: "LB", label: t`Left Balance`},
    {value: "E", label: t`Edge Only`},
    {value: "F", label: t`Frame Only`},
    {value: "A", label: t`Addon`}
]

const FRAMESTATUS_OPTIONS = [
    {value: "", label: t`No Default`},
    {value: "D", label: t`Uncut no Frame`},
    {value: "U", label: t`Uncut with Frame`},
    {value: "L", label: t`Trace Only`},
    {value: "F", label: t`Frame to Follow`},
    {value: "S", label: t`Lab Supplied Frame`},
    {value: "N", label: t`None`}
]

export const ConfigForm: React.FunctionComponent<FormProps> = observer(({model, readOnly}) => {
    const postFormActions = readOnly && model.isUserUpdatable &&
        <LinkButton to={model.store.updateLink(model.getId())} color={"secondary"} noGutter><Edit/> {t`Edit`}
        </LinkButton>

    const isAdmin = currentUserCan('Config', 'user_config_admin');
    const canEdit = currentUserCan("Config", "update") || isAdmin;

    return (
        <Container maxWidth={'lg'}>
            <PaddedPaper>
                <ModelForm model={model} suppressWrapper suppressImportExport suppressMakeCopy={true}
                           readOnly={readOnly || !canEdit} postFormActions={postFormActions}
                           suppressList={!isAdmin}>
                    <Typography variant={'h4'}>{t`Rx-Site User Configuration`}</Typography>
                    <Grid container spacing={4}>
                        <Grid item xs={12}>
                            <ModelInput name={"user_name"} disabled/>
                        </Grid>
                        <Grid item xs={12}>
                            <ModelInput name={"user_email"} disabled/>
                        </Grid>
                        <Grid item xs={12}>
                            <CustomersSelect />
                        </Grid>
                        <Grid item xs={12}>
                            <OrderColumnsSelect />
                        </Grid>
                        <Grid item xs={12}>
                            <ConfigPDSelect />
                        </Grid>
                        <Grid item xs={12}>
                            <ModelSelect name={"default_job_type"} options={JOBTYPE_OPTIONS} />
                        </Grid>
                        <Grid item xs={12}>
                            <ModelSelect name={"default_frame_status"} options={FRAMESTATUS_OPTIONS} />
                        </Grid>
                        <Grid item xs={12}>
                            <ModelCheckbox name={"allow_personalization"} />
                        </Grid>
                        <Conditional condition={currentUserCan('Config', 'user_config_admin')}>
                            <IfTrue>
                                <Grid item xs={12}>
                                    <ModelCheckbox name={"edge_frame"}/>
                                </Grid>
                            </IfTrue>
                        </Conditional>
                        <Grid item xs={12}>
                            <ModelCheckbox name={"continuous_entry"} />
                        </Grid>
                        <Grid item xs={12}>
                            <ModelCheckbox name={"show_confirmation"} />
                        </Grid>
                    </Grid>
                </ModelForm>
            </PaddedPaper>
        </Container>
    );
})