import * as React from 'react';
import {OrderModel} from "../../stores/OrderStore";
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import { makeStyles, Typography } from '@material-ui/core';
import {useSnackbar} from "notistack";

type Props = {
    order: OrderModel
}

const useClasses = makeStyles((theme) => ({
    errorMessage: {
        color: theme.palette.error.main
    }
}))

export const OrderSyncButton: React.FunctionComponent<Props> = ({order}) => {
    const [loading, setLoading] = React.useState(false);
    const [errorMessage, setErrorMessage] = React.useState("");
    const {enqueueSnackbar} = useSnackbar();

    const classes = useClasses();

    const handleClick = React.useCallback(async () => {
        setLoading(true);

        order.resetView();
        const response = await fetch("/api/order_lookups", {
            method: "POST",
            body: JSON.stringify({
                order_number: order.order_number
            }),
            headers: {
                "Content-Type": "application/json"
            }
        })
        const json = await response.json();
        if(response.ok) {
            setErrorMessage("");
            enqueueSnackbar(t`Order synced successfully`, {variant: "success"});
        } else {
            setErrorMessage(json.error);
        }
        setLoading(false);
    }, [order.order_number]);

    if(order.isNew) {
        return null;
    }

    return (
        <>
            <ButtonField
                text={t`Sync`}
                onClick={handleClick}
                loading={loading}
            />
            <Typography variant={"subtitle1"} className={classes.errorMessage}>{errorMessage}</Typography>
        </>


    )
}