class SyncStylesJob < ApplicationJob
  queue_as :default

  def perform(*args)
    StyleSyncStatus.wrap do

      StyleType.quietly do
        Style.update_all(active: false)
      end
      
      data = []
      uncut = []

      last_response = nil
      StyleType.find_each do |style_type|
        offset = 0
        uncut_offset = 0

        loop do
          rxu_styles = RxModule::Communicator::Rxuniverse.styles(
            style_type: style_type.style_type,
            limit: SyncStatus::LIMIT,
            offset: offset
          )

          break if rxu_styles.empty? || rxu_styles == last_response

          last_response = rxu_styles

          rxu_styles.each do
            data << {
              style: _1[:style],
              requires_trace: true,
              description: _1[:description],
              style_type_id: style_type.id,
              active: true
            }
          end

          offset += SyncStatus::LIMIT
        end

        last_response = nil
        loop do
          rxu_styles = RxModule::Communicator::Rxuniverse.styles(
            style_type: style_type.style_type,
            uncut: true,
            limit: SyncStatus::LIMIT,
            offset: uncut_offset
          )

          break if rxu_styles.empty? || last_response == rxu_styles

          last_response = rxu_styles

          rxu_style_codes = rxu_styles.map { _1[:style] }

          uncut.push(*rxu_style_codes)

          uncut_offset += SyncStatus::LIMIT
        end
      end

      Style.quietly do
        data.each do |sty|
          style = Style.unscope(:where).where(style: sty[:style]).first_or_initialize
          style.assign_attributes(sty)
          style.save
        end
        Style.unscope(:where).where(style: uncut).update_all(requires_trace: false)
      end
    end
  end
end
